==> ikaaro-0.50.0.tar.gz: ikaaro-0.50.0/ui/tiny_mce/plugins/advlink/langs/de_dlg.js <==
tinyMCE.addI18n('de.advlink_dlg',{
title:"Link einf\u00FCgen/bearbeiten",
url:"Adresse",
target:"Fenster",
titlefield:"Titel",
is_email:"Bei der Adresse scheint es sich um eine E-Mail-Adresse zu handeln. Wollen Sie das dazu ben\u00F6tigte mailto: voranstellen?",
is_external:"Bei der Adresse scheint es sich um einen externen Link zu handeln. M\u00F6chten Sie, dass zur korrekten Verlinkung ein http:// vorangestellt wird?",
list:"Linkliste",
general_tab:"Allgemein",
popup_tab:"Popup",
events_tab:"Ereignisse",
advanced_tab:"Erweitert",
general_props:"Allemeine Eigenschaften",
popup_props:"Popup-Eigenschaften",
event_props:"Ereignisse",
advanced_props:"Erweiterte Eigenschaften",
popup_opts:"Optionen",
anchor_names:"Anker",
target_same:"Im selben Fenster/Frame \u00F6ffnen",
target_parent:"Im \u00FCbergeordneten Fenster/Frame \u00F6ffnen",
target_top:"Im obersten Frame \u00F6ffnen (sprengt das Frameset)",
target_blank:"In neuem Fenster \u00F6ffnen",
popup:"JavaScript-Popup",
popup_url:"Popup-Adresse",
popup_name:"Name des Fensters",
popup_return:"Link trotz Popup folgen",
popup_scrollbars:"Scrollbalken anzeigen",
popup_statusbar:"Statusleiste anzeigen",
popup_toolbar:"Werkzeugleisten anzeigen",
popup_menubar:"Browsermen\u00FC anzeigen",
popup_location:"Adressleiste anzeigen",
popup_resizable:"Vergr\u00F6\u00DFern des Fenster zulassen",
popup_dependent:"Vom Elternfenster abh\u00E4ngig (nur Mozilla/Firefox)",
popup_size:"Gr\u00F6\u00DFe",
popup_position:"Position (X/Y)",
id:"ID",
style:"Format",
classes:"Klassen",
target_name:"Name der Zielseite",
langdir:"Schriftrichtung",
target_langcode:"Sprache der Zielseite",
langcode:"Sprachcode",
encoding:"Zeichenkodierung der Zielseite",
mime:"MIME-Type der Zielseite",
rel:"Beziehung der Seite zum Linkziel",
rev:"Beziehung des Linkziels zur Seite",
tabindex:"Tabindex",
accesskey:"Tastenk\u00FCrzel",
ltr:"Links nach rechts",
rtl:"Rechts nach links",
link_list:"Linkliste"
});

==> ikaaro-0.50.4.tar.gz: ikaaro-0.50.4/ui/tiny_mce/plugins/advlink/langs/de_dlg.js <==
tinyMCE.addI18n('de.advlink_dlg',{
title:"Link einf\u00FCgen/bearbeiten",
url:"Adresse",
target:"Fenster",
titlefield:"Titel",
is_email:"Bei der Adresse scheint es sich um eine E-Mail-Adresse zu handeln. Wollen Sie das dazu ben\u00F6tigte mailto: voranstellen?",
is_external:"Bei der Adresse scheint es sich um einen externen Link zu handeln. M\u00F6chten Sie, dass zur korrekten Verlinkung ein http:// vorangestellt wird?",
list:"Linkliste",
general_tab:"Allgemein",
popup_tab:"Popup",
events_tab:"Ereignisse",
advanced_tab:"Erweitert",
general_props:"Allemeine Eigenschaften",
popup_props:"Popup-Eigenschaften",
event_props:"Ereignisse",
advanced_props:"Erweiterte Eigenschaften",
popup_opts:"Optionen",
anchor_names:"Anker",
target_same:"Im selben Fenster/Frame \u00F6ffnen",
target_parent:"Im \u00FCbergeordneten Fenster/Frame \u00F6ffnen",
target_top:"Im obersten Frame \u00F6ffnen (sprengt das Frameset)",
target_blank:"In neuem Fenster \u00F6ffnen",
popup:"JavaScript-Popup",
popup_url:"Popup-Adresse",
popup_name:"Name des Fensters",
popup_return:"Link trotz Popup folgen",
popup_scrollbars:"Scrollbalken anzeigen",
popup_statusbar:"Statusleiste anzeigen",
popup_toolbar:"Werkzeugleisten anzeigen",
popup_menubar:"Browsermen\u00FC anzeigen",
popup_location:"Adressleiste anzeigen",
popup_resizable:"Vergr\u00F6\u00DFern des Fenster zulassen",
popup_dependent:"Vom Elternfenster abh\u00E4ngig <br /> (nur Mozilla/Firefox) ",
popup_size:"Gr\u00F6\u00DFe",
popup_position:"Position (X/Y)",
id:"ID",
style:"Format",
classes:"Klassen",
target_name:"Name der Zielseite",
langdir:"Schriftrichtung",
target_langcode:"Sprache der Zielseite",
langcode:"Sprachcode",
encoding:"Zeichenkodierung der Zielseite",
mime:"MIME-Type der Zielseite",
rel:"Beziehung der Seite zum Linkziel",
rev:"Beziehung des Linkziels zur Seite",
tabindex:"Tabindex",
accesskey:"Tastenk\u00FCrzel",
ltr:"Links nach rechts",
rtl:"Rechts nach links",
link_list:"Linkliste"
});
